@@ -1,4 +1,4 @@
-`CLA` <-
+"CLA" <-
 function(Catches,Abund.est,CV.est, multiplier=5, ...) {
  # Keep CLA happy...
  yrs.of.est <- index( !is.na( rowSums( Abund.est))) # won't work if partial ests
@@ -18,3 +18,4 @@ function(Catches,Abund.est,CV.est, multiplier=5, ...) {
 return( TAC)
 }
 
+
