@@ -1,5 +1,4 @@
-`def.depleter` <-
-function(unused1, unused2, bp.polys, rland, TAC){
+def.depleter <- function(unused1, unused2, bp.polys, rland, TAC){
 
 	n.bps <- length(bp.polys)
 	goners <- goner.locs <- vector("list",n.bps)
@@ -14,5 +13,4 @@ function(unused1, unused2, bp.polys, rland, TAC){
 		rland$individuals <- rland$individuals[-goners,]
 	}
 	return(list(rland=rland,goners=goner.locs))
-}
-
+}
\ No newline at end of file
