@@ -1,4 +1,4 @@
-`def.make.schedule` <-
+"def.make.schedule" <-
 function( n.pre.RMP, n.RMP, n.post.RMP=0, abund.gap=5){
   gs.years <- n.pre.RMP # last year before RMP
   pre.RMP.years <- 1 %upto% n.pre.RMP
@@ -13,3 +13,4 @@ function( n.pre.RMP, n.RMP, n.post.RMP=0, abund.gap=5){
 returnList( stop.years, gs.years, abund.est.years, pre.RMP.years, CLA.years, post.RMP.years, BSA.years)
 }
 
+
